@@ -1,4 +1,4 @@
-# Copyright 2016-2024 Geoffrey R. Scheller
+# Copyright 2016-2025 Geoffrey R. Scheller
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,13 @@
 """### Circular Array
 
 Package for an indexable circular array data structure.
+
+#### Modules
+
+* module grscheller.circular_array.ca: circular array Python data structure
+
 """
-__version__ = "3.6.2"
+__version__ = "3.8.1"
 __author__ = "Geoffrey R. Scheller"
-__copyright__ = "Copyright (c) 2023-2024 Geoffrey R. Scheller"
+__copyright__ = "Copyright (c) 2023-2025 Geoffrey R. Scheller"
 __license__ = "Apache License 2.0"
